================
django-oscar-cch
================

|  |license| |kit| |format|

This package handles integration between django-oscar based e-commerce sites and the `CCH Sales Tax Office <http://www.salestax.com/products/calculations-solutions/sales-tax-office.html>`_ SOAP API.

**Full Documentation**: https://django-oscar-cch.readthedocs.io


.. |license| image:: https://img.shields.io/pypi/l/django-oscar-cch.svg
    :target: https://pypi.python.org/pypi/django-oscar-cch
.. |kit| image:: https://badge.fury.io/py/django-oscar-cch.svg
    :target: https://pypi.python.org/pypi/django-oscar-cch
.. |format| image:: https://img.shields.io/pypi/format/django-oscar-cch.svg
    :target: https://pypi.python.org/pypi/django-oscar-cch
